﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using GeoTools.General;

namespace GeoTools.Shapes
{
    internal class Square : GeoBase, IGeoObject
    {
        double length;
        PointF position;

        public Square()
        {
        }
        public Square(List<KeyValuePair<string, double>> args)
        {
            position = new PointF(0,0);
            foreach (var pair in args)
            {
                if (pair.Key == "l")
                    length = pair.Value;
                else if (pair.Key == "x")
                    position.X = (float)(pair.Value);
                else if (pair.Key == "y")
                    position.Y = (float)(pair.Value);
            }
        }
        public Square(double x, double y, double l)
        {
            length = l;
            position = new PointF((float)x, (float)y);
        }
        public Square(PointF p, double l)
        {
            length = l;
            position = p;
        }

        public double Length
        {
            get { return length; }
            set { length = value; }
        }
        public override double Area { get { return length * length; } }
        public override double Perimeter { get { return 4 * length; } }
        public PointF Position { get { return position; } }

        public override string ToString()
        {
            return "square [location:(" + position.X + "," + position.Y + "), edge length:" + length + "]";
        }

        public override void Draw(Graphics g)
        {
            Pen p = new Pen(Brushes.Red, 4);
            g.DrawLine(p, new PointF(position.X, position.Y), new PointF(position.X + (float)length, position.Y));
            g.DrawLine(p, new PointF(position.X + (float)length, position.Y), new PointF(position.X + (float)length, position.Y + (float)length));
            g.DrawLine(p, new PointF(position.X, position.Y + (float)length), new PointF(position.X + (float)length, position.Y + (float)length));
            g.DrawLine(p, new PointF(position.X, position.Y + (float)length), new PointF(position.X, position.Y));
        }

        public double[][] Points
        {
            get
            {
                return new double[][]{
                            new double[] {position.X, position.Y },
                            new double[] { position.X + length, position.Y },
                            new double[] { position.X + length, position.Y + length },
                            new double[] { position.X, position.Y + length }
                    };
            }
        }
    }
}
